function [num_estimator, estimator_idx, num_true_estimator, true_estimator_idx, TPR, FPR, dt] = my_exp(dataset_num, ct, a_T, q, phi, B, Y, X0, beta_true, pmax)
close all

init = 10^2;
T = 10^4;
mu_T = T/(2*a_T);  % number of odd/even blocks
block_seq = 1:mu_T;
num_blocks = floor(mu_T/2); % number of O1/O2 blocks
[T, K] = size(Y);

all_O1_prob = [];
all_O2_prob = [];
fprintf('\n');

all_O1_idx = [];
all_O2_idx = [];

[all_B, lambda_values, lambda_min] = run_lambda_exp(Y, X0, pmax, q, a_T, init);

for n = 1:B  
    O1_idx = sort(randperm(mu_T, num_blocks)); %O1 blocks number
    all_O1_idx = [all_O1_idx; O1_idx];
    u = unique(all_O1_idx, 'rows', 'first');
    hasDuplicates = size(u,1) < size(all_O1_idx,1);
    
    %make sure every run of B is different
    while hasDuplicates == 1  
        all_O1_idx(end,:) = []; %Delete last row
        O1_idx = sort(randperm(mu_T, num_blocks)); %regenerate random O1 blocks number
        all_O1_idx = [all_O1_idx; O1_idx];
        u = unique(all_O1_idx, 'rows', 'first');
        hasDuplicates = size(u,1) < size(all_O1_idx,1);
    end %while duplicate
    
    O2_idx = block_seq(~ismember(block_seq, O1_idx)); %O2 blocks number
    all_O2_idx = [all_O2_idx; O2_idx];
    
    block_start_1 = init+1+(O1_idx-1)*(2*a_T); %O1 blocks index starts
    block_start_2 = init+1+(O2_idx-1)*(2*a_T); %O2 blocks index starts
    
    fprintf('.');
    if mod(n,10)==0
        fprintf('\n');
    end
    
    all_B1 = [];
    all_B2 = [];

    for pos1 = block_start_1
        % Construct y and X
        y = Y(pos1:pos1+a_T-1,1);
        X = [];
        for ii=1:pmax
            X = [X Y(pos1-ii:pos1-ii+a_T-1,1:K)];
        end
        X = [X X0(pos1:pos1+a_T-1,:)];

        [B1, st1] = lasso(X, y, 'Lambda', lambda_min); 
        all_B1 = [all_B1, B1];
          
    end %pos1
    
    for pos2 = block_start_2
        % Construct y and X
        y = Y(pos1:pos1+a_T-1,1);
        X = [];
        for ii=1:pmax
            X = [X Y(pos2-ii:pos2-ii+a_T-1,1:K)];
        end
        X = [X X0(pos2:pos2+a_T-1,:)];
        
        [B2, st2] = lasso(X, y, 'Lambda', lambda_min); 
        all_B2 = [all_B2, B2];
        
    end %pos2
    
    all_count1 = [];
    all_count2 = [];

    for p=1:size(B1,1)
        count_1 = sum(all_B1(p,:)~=0);
        count_2 = sum(all_B2(p,:)~=0);
        all_count1 = [all_count1; count_1];
        all_count2 = [all_count2; count_2];
        
    end %p
    
    O1_prob = all_count1/num_blocks;
    O2_prob = all_count2/num_blocks;
    all_O1_prob = [all_O1_prob, O1_prob];
    all_O2_prob = [all_O2_prob, O2_prob];
        
end %n

all_BPA_prob = [];

for p=1:size(B1,1)
    BPA_prob = (sum(all_O1_prob(p,:))/(2*B))+(sum(all_O2_prob(p,:))/(2*B));
    all_BPA_prob = [all_BPA_prob; BPA_prob];
    
end %p

num_estimator = sum(all_BPA_prob(:,1)>phi);
estimator_idx = find(all_BPA_prob(:,1)>phi);

num_true_estimator = sum(beta_true(:,1)~=0);
true_estimator_idx = find(beta_true(:,1)~=0);

TP = sum(ismember(estimator_idx, true_estimator_idx));
TPR = TP/num_true_estimator;

FP = sum(~ismember(estimator_idx, true_estimator_idx));
FPR = FP/(size(B1,1)-num_true_estimator);

fprintf('\n');

end %function

