function [num_estimator, estimator_idx, num_true_estimator, true_estimator_idx, TPR, FPR] = my_exp(dataset_num, ct, a_T, q, phi, B, Y, X0, beta_true, pmax)

close all

init = 10^2; 
T = 10^4; 
mu_T = T/(2*a_T);  % number of odd/even blocks
block_seq = 1:mu_T;
num_blocks = floor(mu_T/2); % number of O1/O2 blocks
[T, K] = size(Y);

fprintf('\n');

all_O1_idx = [];
all_O2_idx = [];
all_B1 = [];
all_B2 = [];

[all_B, lambda_values, lambda_min] = run_lambda_exp(Y, X0, pmax, q, a_T, init);

for n = 1:B  
    O1_idx = sort(randperm(mu_T, num_blocks)); %O1 blocks number
    all_O1_idx = [all_O1_idx; O1_idx];
    u = unique(all_O1_idx, 'rows', 'first');
    hasDuplicates = size(u,1) < size(all_O1_idx,1);
    
    %make sure every iteration of B is different
    while hasDuplicates == 1  
        all_O1_idx(end,:) = []; %Delete last row
        O1_idx = sort(randperm(mu_T, num_blocks)); %regenerate random O1 blocks number
        all_O1_idx = [all_O1_idx; O1_idx];
        u = unique(all_O1_idx, 'rows', 'first');
        hasDuplicates = size(u,1) < size(all_O1_idx,1);
    end %while duplicate
    
    O2_idx = block_seq(~ismember(block_seq, O1_idx)); %O2 blocks number
    all_O2_idx = [all_O2_idx; O2_idx];
    
    block_start_1 = init+1+(O1_idx-1)*(2*a_T); %O1 blocks index starts
    block_start_2 = init+1+(O2_idx-1)*(2*a_T); %O2 blocks index starts
    
    fprintf('.');
    if mod(n,10)==0
        fprintf('\n');
    end

    %big block O'
    [X, y] = run_block(block_start_1, Y, X0, a_T, pmax);
    
    [B1, st1] = lasso(X, y, 'Lambda', lambda_min); 
    all_B1 = [all_B1, B1];

    %big block O''
    [X, y] = run_block(block_start_2, Y, X0, a_T, pmax);
    
    [B2, st2] = lasso(X, y, 'Lambda', lambda_min); 
    all_B2 = [all_B2, B2];

end %n

all_k_prob1 = [];
all_k_prob2 = [];

for p=1:size(B1,1)
    k_prob1 = sum(all_B1(p,:)~=0)/(2*B);
    k_prob2 = sum(all_B2(p,:)~=0)/(2*B);
    all_k_prob1 = [all_k_prob1; k_prob1];
    all_k_prob2 = [all_k_prob2; k_prob2];
end %p

BPA_prob = all_k_prob1+all_k_prob2;

pre_phi_num_estimator = sum(BPA_prob(:,1)>0);

num_estimator = sum(BPA_prob(:,1)>=phi);
estimator_idx = find(BPA_prob(:,1)>=phi);

num_true_estimator = sum(beta_true(:,1)~=0);
true_estimator_idx = find(beta_true(:,1)~=0);

TP = sum(ismember(estimator_idx, true_estimator_idx));
TPR = TP/num_true_estimator; %TPR=TP/(TP+FN)

FP = sum(~ismember(estimator_idx, true_estimator_idx));
FPR = FP/(size(B1,1)-num_true_estimator); %FPR=FP/(FP+TN)

fprintf('\n');

formatSpec = 'exp_results/data_results/ct_%.1f/data_%d_aT_%d_q_%d_phi_%.1f_B_%d_exp_result.mat'; %local
fname = sprintf(formatSpec,ct,dataset_num, a_T, q, phi, B)
save(fname,'all_B', 'lambda_values','lambda_min','all_O1_idx', 'all_O2_idx', 'all_B1', 'all_B2','all_k_prob1', 'all_k_prob2','estimator_idx','true_estimator_idx', 'pre_phi_num_estimator', 'TPR', 'FPR');   % save variable in the output.mat file


end %function

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [X, y] = run_block(block_start, Y, X0, a_T, pmax)
    %big block O'
    X = [];
    y = [];
    for pos1 = block_start
        % Construct y and X
        y = [y; Y(pos1:pos1+a_T-1,1)];
        Xtemp = [];
        for ii=1:pmax 
            Xtemp = [Xtemp Y(pos1-ii:pos1-ii+a_T-1,:)]; 
        end
        Xtemp = [Xtemp X0(pos1:pos1+a_T-1,:)];
        X = [X; Xtemp];
    end %pos1
    
end



