function [all_B, lambda_values, lambda_min] = run_lambda_exp(Y, X0, pmax, q, a_T, init)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Input:
% q   = active entries of B
% q   = 40;
% ct  = 0.25;
% a_T = 100;  % each data set is divided into blocks of length 50,100 and 200
% distb = 100;    % a gap of length distb(init) between any two consecutive blocks
% [Y, X0, beta_true, ~, pmax, ~] = gendata(ct, init);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

close all

[T, K] = size(Y);

pos = init+1; %pos: where the block start

% Construct y and X
y = Y(pos:end,1);
a_T = length(y);
X = [];
    
for ii=1:pmax 
    X = [X Y(pos-ii:pos-ii+a_T-1,:)];
end
    
X = [X X0(pos:pos+a_T-1,:)];

[all_B, st] = lasso(X,y);   % lasso identifies and removes the redundant predictors.
                        % B: Each column of B corresponds to a particular regularization coefficient in Lambda.
                        % B is a p-by-L matrix, where p is the number of predictors (columns) in X, and L is the number of Lambda values.
                        % st: the structure FitInfo [Lambda parameters in ascending order, a 1-by-L vector]
                        %everytime run lasso gives same B

% np = size(X,2); %Query only the length of the second dimension of X.
lambda_values = st.Lambda;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Create figure window
%figure(1);  
%plot(1:np,B(:,min(100,size(B,2))),'k',1:np,beta_true,'r'); % lasso in black and true in red
%legend('lasso','true');
%tit = sprintf('Block no. %i, lambda=%5.4f', count, st.Lambda(min(50,size(B,2) )));
%title(tit);

%pause   % stop and wait for you to press any key before continuing
%fprintf('Press a key!\n');  % displays formatted text
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% active_variables = sum(all_B(:,1)~=0);
    
for i=1:size(all_B,2) %size(B,2)=L number of Lambda values
    num_variables = sum(all_B(:,i)~=0); %number of active entries of B.
    if num_variables <= q %uncertain about whether can get exactly q active variables, so I use <=
        break
    end
end
    
lambda_min = st.Lambda(i); %the smallest λ that returns q active entries of B.

% [B, st] = lasso(X,y, 'Lambda', lambda_min); 
% active_variables_1 = sum(B(:,1)~=0); %number of active entries decreases
    
end %function

