function [all_B, lambda_values, lambda_min] = run_lambda_exp(Y, X0, q)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Input:
% q   = active entries of B
% q   = 40;
% ct  = 0.25;
% a_T = 100;  % each data set is divided into blocks of length 50,100 and 200
% distb = 100;    % a gap of length distb(init) between any two consecutive blocks
% [Y, X0, beta_true, ~, pmax, ~] = gendata(ct, init);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

close all


%pos = init+1; %pos: where the block start

% Construct y and X
%y = Y(pos:pos+a_T-1,1);
%X = [];
    
% for ii=1:pmax
%     X = [X Y(pos-ii:pos-ii+a_T-1,1:K)];
% end
    
% X = [X X0(pos:pos+a_T-1,:)];
% if (size(Y,2)~=1) || (size(X0,1)~=size(Y,1))
%     return;
% end
[all_B, st] = lasso(X0,Y);   % lasso identifies and removes the redundant predictors.
                        % B: Each column of B corresponds to a particular regularization coefficient in Lambda.
                        % B is a p-by-L matrix, where p is the number of predictors (columns) in X, and L is the number of Lambda values.
                        % st: the structure FitInfo [Lambda parameters in ascending order, a 1-by-L vector]
                        %everytime run lasso gives same B
                        
% np = size(X,2); %Query only the length of the second dimension of X.
lambda_values = st.Lambda;

% active_variables = sum(all_B(:,1)~=0);
    
for i=1:size(all_B,2) %size(B,2)=L number of Lambda values
    num_variables = sum(all_B(:,i)~=0); %number of active entries of B.
    if num_variables <= q %uncertain about whether can get exactly q active variables, so I use <=
        break
    end
end
    
lambda_min = st.Lambda(i); %the smallest λ that returns q active entries of B.

% [B, st] = lasso(X,y, 'Lambda', lambda_min); 
% active_variables_1 = sum(B(:,1)~=0); %number of active entries decreases


num_variables_mat = [];
for j=1:size(all_B,2) %size(B,2)=L number of Lambda values
    num_variables = sum(all_B(:,j)~=0); %number of active entries of B.
    num_variables_mat = [num_variables_mat, num_variables]
end
% figure(3)
% plot(lambda_values, 'b*-');
% 
% % Add a red line.
% plot(num_variables_mat, 'r*-');
% hold on
% xline(i)
% pause

tiledlayout(2,1)

% Top plot
nexttile
plot(lambda_values, 'b*-')
xlabel('$$\lambda\ \mathrm{index}$$','interpreter','latex')
ylabel('$$\lambda$$','interpreter','latex')
xline(i)


% Bottom plot
nexttile
plot(num_variables_mat, 'r*-')
xlabel('$$\lambda\ \mathrm{index}$$','interpreter','latex')
ylabel('Number of active entries', 'FontSize',12,'FontWeight','bold')
xline(i)
pause

end %function

