function [Y, X0, beta_true, spec_rad, pmax, s] = gendata(ct, init)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Input:
% (ct   = variance for errors is cs^2     %not std.) 
% ct   = std. for errors is ct*cs
% init = no. of samples initialization
%Output:
% Y             = matrix measurements (T X K)
% X0            = matrix ex. var. (T X s)
% beta_true     = vector true values all pred. (100 X 1) [predictor is included or not]
% spec_rad      = spectral radius VAR
% pmax          = max. VAR order used in estimation
% s             = total number ex. predictors
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
K                                   = 4;                        %no. time series
p                                   = 3;                        %true VAR order
pmax                                = 4;                        %max VAR order
c                                   = zeros(K,1);               %intercept
pz                                  = 0.6;                      %max prob. of zero entries VAR coeff.
cs                                  = 0.25;                     %std of matrix coefficients, cs^2 is the variance of the coefficients
[Atrue, ~, spec_rad]                = gen_coeff(K, p, cs, pz);  %VAR coeff.
s                                   = 100 - pmax*K;             %number ex. predictors 100 - pmax*K;    
Beta                                = zeros(K,s);
beta                                = [ones(1,3) zeros(1,s-3)]; %coeff. ex. predictors
Beta(1,:)                           = beta;
Sigma                               = (cs*ct)^2*eye(K);         %variance of noise is (cs*ct)^2
Mdl                                 = varm('Constant', c, ...   %Create vector autoregression (VAR) model
                                        'AR', Atrue, ...
                                        'Beta', Beta, ...
                                        'Covariance', Sigma);
T                           = 10^4+init;                        %total no. of samples   
X0                          = cs*randn(T+init,s);               %ex. predictors. randn: Normally distributed random numbers
X0(:,1)                     = gen_ar1([1 0.9], X0(:,1));        %AR(1)
                                                                %[1 0.9]:Order the coefficients in ascending powers
X0(:,2)                     = gen_ar1([1 0.5], X0(:,2));        %AR(1)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
[Y,~]                       = simulate(Mdl,T+init,'X',X0);      %generate data (Monte Carlo simulation of ARIMA or ARIMAX models)
                                                                %numObs:(T+init) observations
                                                                %X:Matrix of predictor data with length Mdl.Beta columns of separate series. 
                                                                %X:The number of observations (rows) of X must equal or exceed numObs. 
                                                                
Y                           = Y(init+1:end,:);                  %discard init. values (simulated)
X0                          = X0(init+1:end,:);                 %discard init. values ex. pred.
At                          = cell2mat(Atrue);                  %cell2mat:Convert cell array to ordinary array of the underlying data type
beta_true                   = [At(1,:)'                         %true values all pred. 
                                zeros(1,(pmax-p)*K)'
                                beta'];

end %function                            


            
